<div align="center">

<img src="logo.png" width="25%" height="25%" width="400px">

**When you feel the need...for an awesome Python package!**

______________________________________________________________________

<p align="center">
  <a href="https://need4swede.net">Documentation</a> •
  <a href="#installation">Installation</a> •
  <a href="#contributing">Contributing</a>
</p>

[![PyPI Status](https://badge.fury.io/py/n4s.svg)](https://badge.fury.io/py/n4s.svg)
[![PyPI Status](https://pepy.tech/badge/n4s)](https://pepy.tech/project/n4s)
[![ReadTheDocs](https://readthedocs.org/projects/mlsync/badge/?version=latest)](https://need4swede.netlify.app/)


</div>

## Installation

```sh
pip install n4s
```

### What is n4s?

This library isn't going to revolutionize how you use Python, but it will save you some money on hair loss treatments and ibuprofen. This package is an amalgamation of years spent writing Python code and trying to simplify certain common tasks to make them far more readable.

Whether you're new to Python or a veteran snake charmer, n4s is here to make your code cleaner, more intuative and easier to write.

### Why use n4s?

Because writing Python code shouldn't be hard or tedious - regardless of experience and skill level.
This library expedites basic Python functionality, so you can focus on the more complex modules of your applications. This will help you save dev time, make your code cleaner and elminiate redundancy. 

## Contributing

If you would like to contribute, please feel free to open an issue or pull request. Or, if you have any feedback or suggestions, please [contact me](mailto:contact@mafshari.work) directly. I would be happy to hear from you!